@@ -1,6 +1,9 @@
 #!/usr/bin/env python3
 #
 #  options.py
+"""
+Reusable options for click.
+"""
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
@@ -30,10 +33,15 @@ from typing import Callable
 import click
 from domdf_python_tools.stringlist import DelimitedList
 
-__all__ = ["token_option", "version_callback"]
+__all__ = ["token_option", "version_callback", "org_option"]
 
 
 def token_option(token_var: str = "GITHUB_TOKEN") -> Callable:  # nosec: B107
+	"""
+	Creates a ``-t / --token`` option for the GitHub API token.
+
+	:param token_var:
+	"""
 
 	return click.option(
 			"-t",
@@ -48,7 +56,25 @@ def token_option(token_var: str = "GITHUB_TOKEN") -> Callable:  # nosec: B107
 			)
 
 
-def version_callback(ctx, param, value):
+def org_option() -> Callable:
+	"""
+	Creates a ``--org`` option to specify that the repository belongs to an organisation.
+
+	.. versionadded: 0.3.0
+	"""
+
+	desc = "Indicates the repository belongs to the organisation configured as 'username' in repo_helper.yml."
+
+	return click.option(
+			"--org",
+			type=click.STRING,
+			help=desc,
+			is_flag=True,
+			default=False,
+			)
+
+
+def version_callback(ctx, param, value):  # noqa: D103
 	# 3rd party
 	import repo_helper
 
